.. sysscope documentation master file, created by
   sphinx-quickstart on Sun Nov 14 09:50:21 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=========================
sysscope's documentation
=========================

Copyright 2012 `George Notaras`_ <gnot [at] g-loaded.eu>

.. _`George Notaras`: http://www.g-loaded.eu/

Welcome to the *sysscope*'s documentation!


About this project
==================

sysscope - Tool for visual representation of RRDtool's Round Robin Databases.

| **Author**: `George Notaras <http://www.g-loaded.eu/>`_
| **Development Web Site**: `sysscope project <http://www.codetrax.org/projects/sysscope>`_
| **Source Code Repository**: `sysscope source code <https://source.codetrax.org/hgroot/sysscope>`_
| **Documentation**: `sysscope documentation <http://packages.python.org/sysscope>`_
| **Downloads**: `sysscope releases <http://pypi.python.org/pypi/sysscope>`_


About this guide
================

This guide provides an introduction to the *sysscope* |version| release,
including instructions about how to install, configure and use it in
Django projects or individual Django applications.

The contents of this documentation (the "*Documentation*") are subject to the
*Apache License, Version 2.0* (the "*License*"); you may only use this
Documentation if you comply with the terms of this License.

A copy of the License exists in the product distribution; the *LICENSE* file.
For copyright and other important notes regarding this release please read
the *NOTICE* file.


Contents:

.. toctree::
   :maxdepth: 2
   
   introduction
   installation
   configuration
   usage
   faq


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. seealso::

    * All projects_ published by CodeTRAX.
    * The official `Django Documentation`_.

.. _projects: http://www.codetrax.org/projects
.. _`Django Documentation`: http://docs.djangoproject.com/en/

